@@ -33,6 +33,8 @@ Library for detecting the current OS, including detecting specific
 Linux distributions. 
 """
 
+from __future__ import print_function
+
 import os
 import sys
 import subprocess
@@ -444,3 +446,9 @@ OsDetect.register_default(OS_OSX, OSX())
 OsDetect.register_default(OS_RHEL, Rhel())
 OsDetect.register_default(OS_UBUNTU, LsbDetect("Ubuntu"))
     
+
+if __name__ == '__main__':
+    detect = OsDetect()
+    print("OS Name:     %s"%detect.get_name())
+    print("OS Version:  %s"%detect.get_version())    
+    print("OS Codename: %s"%detect.get_codename())    
